@@ -3,7 +3,6 @@ from .zxcvbn_rs_py import (
     CrackTimesSeconds,
     Entropy,
     Feedback,
-    Score,
     Suggestion,
     Warning,
     __version__,
@@ -15,7 +14,6 @@ __all__ = [
     "CrackTimesSeconds",
     "Entropy",
     "Feedback",
-    "Score",
     "Suggestion",
     "Warning",
     "__version__",
